;----------------------------------------------------------------------
; Concepts illustrated
;   - Superimposing line contours / filled contours
;   - Drawing polylines
;   - Hatched polygons
;   - Adding text
;   - Python colorbars for NCL

load "$NCARG_ROOT/lib/ncarg/nclscripts/csm/gsn_code.ncl"
load "$NCARG_ROOT/lib/ncarg/nclscripts/csm/gsn_csm.ncl"
load "$NCARG_ROOT/lib/ncarg/nclscripts/csm/contributed.ncl"
load "$NCARG_ROOT/lib/ncarg/nclscripts/csm/shea_util.ncl"
load "$NCARG_ROOT/lib/ncarg/nclscripts/csm/Nicolas.ncl"
;load "/Users/nbarrier/Dropbox/svgconverter/svgtocmap.ncl"
load "/Users/Nicolas/Dropbox/svgconverter/svgtocmap.ncl"

begin
  
  ;         0     1     2     3     4     5     6     7     8     9    10    11    12    
  names=(/"dso","ifo","fso","mdn","non","bar","mar","42e","42w","baf","hud","its","spu"/) ; names of the sections

  ; Definition of the section coordinates (cf fichier matlab)
  dsox=(/-34,-22/)
  dsoy=(/68.,65.5/)
  ifox=(/-15.,-7.5/)
  ifoy=(/65.,62.5/)    
  fsox=(/-7.5,-5./)
  fsoy=(/62.5,58./) 
  mdnx=(/-3,7/)
  mdny=(/57,60/)
  nonx=(/-22.,-0.5,15./)
  nony=(/77.5,77.,78./)
  barx=(/18,15/)
  bary=(/69,78/)
  marx=(/-21.065, -34.685, -35.459/)
  mary=(/64.86,   56.189, 53.036/)
  qdex=(/-35.459,  -9./)
  qdey=(/53.036,  52./)
  qdwx=(/-35.459, -53./)
  qdwy=(/53.036,47./)
  bafx=(/-64,-52/)
  bafy=(/66,67/)
  hudx=(/-65,-66/)
  hudy=(/59,64/) 
  itsx=(/-6,-4/)
  itsy=(/55,57/)  
  spux=(/-56.355,-56.2/)
  spuy=(/52.406,51.223/)

  ; points coordinates
  xm=(/-28.0+2, -11.25, -6.25+0.5, 0.0, -2.5, 17.0+0.5, -29.403000000000002-3, -22.2295000000000020+1, -43.229500000000002-4, -60.0+2, -63.5, -5.0-1.5, -56.277500000000003+1.5/) 
  ym=(/66.75+0.5, 63.75+1, 60.25+1, 56.5+2.5, 77.5+0.5, 73.5, 58.028333333333336+1, 49.518000000000001+4, 48.0180000000000010, 67.5-2, 61.0, 56.0, 51.814499999999995/)
  xm(4)=0
  xm(5)=20-0.3
  ym(5)=ym(5)-0.5
  xm(6)=-36.5
  ym(6)=55
  xm(8)=-42.5
  ym(8)=50-0.25
  xm(7)=-17
  ym(7)=ym(7)-0.2
  xm(0)=-30
  ym(0)=66
  xm(1)=-10
  ym(1)=ym(1)-.5
  xm(2)=-5

  ; Define the bathymetry colormap
  NCOL=128
  cmap=svgconv("Blues_09",NCOL)
  
  ; domain limitation
  latmin=45
  latmax=80
  lonmin=-70
  lonmax=25

  ; Load the gebco bathymetry
  dirin="/Users/Nicolas/Downloads/gebco_for_ncl.nc"
  ;dirin="/Users/nbarrier/Desktop/gebco_for_ncl.nc"
  fin=addfile(dirin,"r")
  stride=1
  loni=fin->lon(0,:) ; longitude
  lati=fin->lat(:,0) ; latitude
  bathyi=fin->bathy(:,:) ; model bathymetry

  ; Interpolate the bathymetry to lower resolution
  minlon=min(loni)
  maxlon=max(loni)
  minlat=min(lati)
  maxlat=max(lati)
  N=500
  lon=fspan(minlon,maxlon,N)
  lat=fspan(minlat,maxlat,N)
  pi = 4.*atan(1.0)
  rad = (pi/180.)
  coslat = cos(lati*rad)
  bathy= area_hi2lores (loni,lati,bathyi, False,coslat,  lon,lat, False)

  wks=gsn_open_wks("pdf","./"+get_script_prefix_name()) ; opening of the workspace
 
  ; merge two colormaps.
  cmap2=(/"plum1","gold","indianred1","firebrick","DarkBlue"/)
  gsn_merge_colormaps(wks,cmap,cmap2)
 
  ; add some gray shadings
  g=0.6
  newindex=NhlNewColor(wks,g,g,g)
  g=0.8
  newindex2=NhlNewColor(wks,g,g,g) 
  g=0.75
  newindex3=NhlNewColor(wks,g,g,g)

  ; ------------------------------------------------------------------------ Draw the bathymetry  

  res=True
  
  ; gsn resources
  res@gsnDraw=False
  res@gsnFrame=False
  res@gsnAddCyclic=False

  ;sf resources
  res@sfXArray=lon
  res@sfYArray=lat
  
  ; cn resources
  levels=create_levels(0,4,0.25) ; levels
  res@cnFillOn=True
  res@cnLevelSelectionMode="ExplicitLevels"
  res@cnLevels=-(/0.5,1,2,3,4,5/);create_levels(0,10,1)
  res@cnLinesOn=False
  res@cnLineColor=0
  res@cnFillDrawOrder="PreDraw"
  res@cnMonoLineColor=True
  res@cnLineLabelsOn=False
  res@cnInfoLabelOn=False
 
  ; mp resource
  res@mpGridAndLimbOn=False
  res@mpGridLineDashPattern=2
  res@mpGridLatSpacingF=5
  res@mpGridLonSpacingF=5

  ; gsn resourse
  res@gsnSpreadColors=True
  res@gsnMaskLambertConformal = True
  res@gsnSpreadColorEnd=2
  res@gsnSpreadColorStart=100  
  res@gsnSpreadColorEnd=2
  res@gsnSpreadColorStart=100

  ; mp resources
  res@mpLimitMode="LatLon" 
  res@mpOutlineOn=True
  res@mpMinLatF=latmin
  res@mpMinLonF=lonmin
  res@mpMaxLatF=latmax
  res@mpMaxLonF=lonmax
  res@mpFillOn=True
  res@mpLandFillColor=1
  res@mpInlandWaterFillColor=0  
  res@mpProjection="LambertConformal"
  res@mpPerimOn=True
  res@mpFillDrawOrder="Draw"
  res@mpGridAndLimbDrawOrder="PostDraw"
  res@mpGridLineColor=50

  ; lb resources
  res@lbLabelStride=4
  res@lbTitleString="Bathymetry (km)"
  res@lbTitlePosition="Bottom"
  res@lbTitleFontHeightF=0.012
  res@lbLabelBarOn=False
 
  ; draw the bathymetry
  map=gsn_csm_contour_map(wks,-bathy(:,:),res) ; draw the filled contours
  ; if no bathymetry, draw a map
  ;map=gsn_csm_map(wks,res)

  
  ;resources for the filled polygones
  polres=True
  polres@tfPolyDrawOrder ="Draw"
  

  ; ------------------------------------------------------------------------ Draw the filled polygons 
  ; Definiton domaine west subpolaire
  x=(/-21.065, -34.685, -35.459,-35.459, -53.,-56.355, -56.2,-65, -66,-64, -52,-34, -22/)
  y=(/64.86,   56.189, 53.036,53.036,47.,52.406,  51.223,59, 64,66, 67,68.,   65.5/)
  polres@gsFillIndex=2
  polres@gsFillColor=130
  dum14=gsn_add_polygon(wks,map,x,y,polres)
  delete(x)
  delete(y)

  ; Definition domaine east subpolaire
  x=(/-6, -4,-5.,-7.5,-7.5,-15. ,-21.065,-34.685,-35.459,-35.459,-9.0/)
  y=(/55, 57,58.,62.5,62.5,65.,64.86,   56.189, 53.036,53.036,52/)
  polres@gsFillIndex=3
  polres@gsFillColor=131
  dum15=gsn_add_polygon(wks,map,x,y,polres)
  delete(x)
  delete(y)

  ; Definition domaine Nordic Seas
  x=(/-34, -22,-15. ,  -7.5,-7.5, -5.,-3 , 7,18, 15,15,-0.5,-22/)
  y=(/68.,   65.5,65.,   62.5,62.5,  58.,57, 60,69, 78,78,77,77.5/)
  polres@gsFillIndex=4
  polres@gsFillColor=132
  dum16=gsn_add_polygon(wks,map,x,y,polres)
  delete(x)
  delete(y)

  ; ------------------------------------------------------------------------ Draw the section lines
  
  ; section lines resources
  lres=True
  lres@gsLineThicknessF = 3.0            ; line thickness   
  lres@gsLineColor      = "black"      ; color of lines
  ; Trace des lignes!!!!
  dum1 = gsn_add_polyline(wks,map,dsox , dsoy ,lres)
  dum2 = gsn_add_polyline(wks,map,ifox , ifoy ,lres)
  dum3 = gsn_add_polyline(wks,map,fsox , fsoy ,lres)
  dum5 = gsn_add_polyline(wks,map,marx , mary ,lres)
  dum6 = gsn_add_polyline(wks,map,qdwx , qdwy ,lres)
  dum7 = gsn_add_polyline(wks,map,qdex , qdey ,lres)
  dum9 = gsn_add_polyline(wks,map,bafx , bafy ,lres)
  dum10 = gsn_add_polyline(wks,map,hudx , hudy ,lres)
  dum11 = gsn_add_polyline(wks,map,mdnx , mdny ,lres)
  dum12 = gsn_add_polyline(wks,map,nonx , nony ,lres)
  dum13 = gsn_add_polyline(wks,map,barx , bary ,lres)
  dum160 = gsn_add_polyline(wks,map,itsx , itsy ,lres)
  dum133 = gsn_add_polyline(wks,map,spux , spuy ,lres)
 
  ; ------------------------------------------------------------------------ Draw the section names
  
  ; Text resources
  txres               = True
  txres@txFontHeightF = 0.007
  txres@txFontHeightF = 0.006
  txres@txFont        = "helvetica-bold"
  txres@txJust ="center"
  txres@txFontColor=lres@gsLineColor
  
  ; texte 1
  txres@txAngleF=8
  text0 = gsn_add_text(wks,map,"42W",-40,50.5,txres)
  ; texte 2
  txres@txAngleF=0
  text1 = gsn_add_text(wks,map,"42E",-17.5,51.5,txres)
  ; texte 3
  txres@txAngleF=0
  text1 = gsn_add_text(wks,map,"NON",-12,78.,txres)
  ; texte 4
  txres@txAngleF=310
  text1 = gsn_add_text(wks,map,"BAR",22.5,73,txres)
  ; texte 5
  txres@txAngleF=52
  text1 = gsn_add_text(wks,map,"MDN",1.5,57.25,txres)
  ; texte 6
  txres@txAngleF=75
  text1 = gsn_add_text(wks,map,"MAR",-33.5,55,txres)
  ; texte 7
  txres@txAngleF=55
  text1 = gsn_add_text(wks,map,"HUD",-67.5,60.5,txres)
  ; texte 8
  txres@txAngleF=337
  text1 = gsn_add_text(wks,map,"BAF",-58,67.5,txres) 
  ; texte 11
  txres@txAngleF=300
  text1 = gsn_add_text(wks,map,"FSO",-4,59.55,txres)
  
  txres@txAngleF=50
  txres@txFontColor="white"
  text1 = gsn_add_text(wks,map,"DSO",-36.5,68.5,txres)  

  txres@txAngleF=0
  text1 = gsn_add_text(wks,map,"IFO",-17.5,65,txres)
  
  ;-------------------------------------------------------------------- Draw the markers

  style="~F34~7"
  txres2 = True 
  txres2@txFontColor="black"
  txres2@txFontHeightF = 0.012
  txres2@txFontThicknessF = 0.1

  do i=0,10
    text1=gsn_add_text(wks,map,style,xm(i),ym(i),txres2) ; . = draw arrow pointing 
  end do

  ;-------------------------------------------------------------------- Add the labels to the projection

  add_lc_labels(wks,map,latmin,latmax,lonmin,lonmax) 

  lbres                    = True          ; labelbar only resources
  lbres@lbAutoManage       = True          ; Necessary to control sizes
  lbres@vpWidthF           = 0.08 * 1     ; labelbar width
  lbres@vpHeightF          = 0.1 * 1     ; labelbar height
  lbres@lbBoxMajorExtentF  = 0.6         ; puts space between color boxes
  lbres@lbFillColors       = (/130,131,132,133,129,1/)  ; labelbar colors
  lbres@lbMonoFillPattern  = False          ; Solid fill pattern
  lbres@lbFillPatterns=(/2,3,4,0,0,4/)
  lbres@lbLabelFontHeightF = 0.001          ; font height. default is small
  lbres@lbLabelFontHeightF = 0.001          ; font height. default is small
  lbres@lbLabelJust        = "CenterLeft"  ; left justify labels
  lbres@lbMonoFillScale=False
  lbres@lbFillScales=(/0.5,0.5,0.5,0.5,0.5,0.2/)
  lbres@lbFillBackground=0
  lbres@lbPerimFillColor=0
  lbres@lbPerimFill="SolidFill"

  labels=(/"WSPG","ESPG","NS","Warm currents","Cold currents","Convection area"/)
  lbid = gsn_create_labelbar(wks,6,labels,lbres)

  amres = True
  amres@amZone           = 2
  amres@amParallelPosF   = 0.83            ; Center labelbar.
  amres@amOrthogonalPosF = -0.5            ; Move down, away from plot
  annoid = gsn_add_annotation(map,lbid,amres)

  ;drawNDCGrid(wks)
  
  draw(map)
  frame(wks)

end